@@ -49,6 +49,7 @@ __all__ = (
     "SplitType",
     "SyntaxLanguageCodeType",
     "ServiceName",
+    "PaginatorName",
 )
 
 
@@ -411,10 +412,12 @@ ServiceName = Literal[
     "transcribe",
     "transfer",
     "translate",
+    "voice-id",
     "waf",
     "waf-regional",
     "wafv2",
     "wellarchitected",
+    "wisdom",
     "workdocs",
     "worklink",
     "workmail",
@@ -422,3 +425,13 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+PaginatorName = Literal[
+    "list_document_classification_jobs",
+    "list_document_classifiers",
+    "list_dominant_language_detection_jobs",
+    "list_entities_detection_jobs",
+    "list_entity_recognizers",
+    "list_key_phrases_detection_jobs",
+    "list_sentiment_detection_jobs",
+    "list_topics_detection_jobs",
+]
